@@ -16,15 +16,15 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
-from google.api_core.client_options import ClientOptions
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
+from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -32,9 +32,10 @@ except AttributeError:  # pragma: NO COVER
     OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
 from google.cloud.dataqna_v1alpha.types import auto_suggestion_service
-from .transports.base import AutoSuggestionServiceTransport, DEFAULT_CLIENT_INFO
-from .transports.grpc_asyncio import AutoSuggestionServiceGrpcAsyncIOTransport
+
 from .client import AutoSuggestionServiceClient
+from .transports.base import DEFAULT_CLIENT_INFO, AutoSuggestionServiceTransport
+from .transports.grpc_asyncio import AutoSuggestionServiceGrpcAsyncIOTransport
 
 
 class AutoSuggestionServiceAsyncClient:
@@ -284,14 +285,13 @@ class AutoSuggestionServiceAsyncClient:
         r"""Gets a list of suggestions based on a prefix string.
         AutoSuggestion tolerance should be less than 1 second.
 
-
         .. code-block:: python
 
             from google.cloud import dataqna_v1alpha
 
-            def sample_suggest_queries():
+            async def sample_suggest_queries():
                 # Create a client
-                client = dataqna_v1alpha.AutoSuggestionServiceClient()
+                client = dataqna_v1alpha.AutoSuggestionServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = dataqna_v1alpha.SuggestQueriesRequest(
@@ -299,7 +299,7 @@ class AutoSuggestionServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.suggest_queries(request=request)
+                response = await client.suggest_queries(request=request)
 
                 # Handle the response
                 print(response)
@@ -335,7 +335,12 @@ class AutoSuggestionServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -349,7 +354,9 @@ class AutoSuggestionServiceAsyncClient:
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution("google-cloud-dataqna",).version,
+        gapic_version=pkg_resources.get_distribution(
+            "google-cloud-dataqna",
+        ).version,
     )
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
