@@ -16,32 +16,34 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
-from google.api_core.client_options import ClientOptions
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
+from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
 except AttributeError:  # pragma: NO COVER
     OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
+from google.protobuf import any_pb2  # type: ignore
+from google.protobuf import field_mask_pb2  # type: ignore
+from google.protobuf import timestamp_pb2  # type: ignore
+
+from google.cloud.dataqna_v1alpha.types import user_feedback as gcd_user_feedback
 from google.cloud.dataqna_v1alpha.types import question
 from google.cloud.dataqna_v1alpha.types import question as gcd_question
 from google.cloud.dataqna_v1alpha.types import question_service
 from google.cloud.dataqna_v1alpha.types import user_feedback
-from google.cloud.dataqna_v1alpha.types import user_feedback as gcd_user_feedback
-from google.protobuf import any_pb2  # type: ignore
-from google.protobuf import field_mask_pb2  # type: ignore
-from google.protobuf import timestamp_pb2  # type: ignore
-from .transports.base import QuestionServiceTransport, DEFAULT_CLIENT_INFO
-from .transports.grpc_asyncio import QuestionServiceGrpcAsyncIOTransport
+
 from .client import QuestionServiceClient
+from .transports.base import DEFAULT_CLIENT_INFO, QuestionServiceTransport
+from .transports.grpc_asyncio import QuestionServiceGrpcAsyncIOTransport
 
 
 class QuestionServiceAsyncClient:
@@ -244,9 +246,9 @@ class QuestionServiceAsyncClient:
 
             from google.cloud import dataqna_v1alpha
 
-            def sample_get_question():
+            async def sample_get_question():
                 # Create a client
-                client = dataqna_v1alpha.QuestionServiceClient()
+                client = dataqna_v1alpha.QuestionServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = dataqna_v1alpha.GetQuestionRequest(
@@ -254,7 +256,7 @@ class QuestionServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_question(request=request)
+                response = await client.get_question(request=request)
 
                 # Handle the response
                 print(response)
@@ -317,7 +319,12 @@ class QuestionServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -338,9 +345,9 @@ class QuestionServiceAsyncClient:
 
             from google.cloud import dataqna_v1alpha
 
-            def sample_create_question():
+            async def sample_create_question():
                 # Create a client
-                client = dataqna_v1alpha.QuestionServiceClient()
+                client = dataqna_v1alpha.QuestionServiceAsyncClient()
 
                 # Initialize request argument(s)
                 question = dataqna_v1alpha.Question()
@@ -353,7 +360,7 @@ class QuestionServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.create_question(request=request)
+                response = await client.create_question(request=request)
 
                 # Handle the response
                 print(response)
@@ -424,7 +431,12 @@ class QuestionServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -445,9 +457,9 @@ class QuestionServiceAsyncClient:
 
             from google.cloud import dataqna_v1alpha
 
-            def sample_execute_question():
+            async def sample_execute_question():
                 # Create a client
-                client = dataqna_v1alpha.QuestionServiceClient()
+                client = dataqna_v1alpha.QuestionServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = dataqna_v1alpha.ExecuteQuestionRequest(
@@ -456,7 +468,7 @@ class QuestionServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.execute_question(request=request)
+                response = await client.execute_question(request=request)
 
                 # Handle the response
                 print(response)
@@ -528,7 +540,12 @@ class QuestionServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -548,9 +565,9 @@ class QuestionServiceAsyncClient:
 
             from google.cloud import dataqna_v1alpha
 
-            def sample_get_user_feedback():
+            async def sample_get_user_feedback():
                 # Create a client
-                client = dataqna_v1alpha.QuestionServiceClient()
+                client = dataqna_v1alpha.QuestionServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = dataqna_v1alpha.GetUserFeedbackRequest(
@@ -558,7 +575,7 @@ class QuestionServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_user_feedback(request=request)
+                response = await client.get_user_feedback(request=request)
 
                 # Handle the response
                 print(response)
@@ -617,7 +634,12 @@ class QuestionServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -635,14 +657,13 @@ class QuestionServiceAsyncClient:
         r"""Updates user feedback. This creates user feedback if
         there was none before (upsert).
 
-
         .. code-block:: python
 
             from google.cloud import dataqna_v1alpha
 
-            def sample_update_user_feedback():
+            async def sample_update_user_feedback():
                 # Create a client
-                client = dataqna_v1alpha.QuestionServiceClient()
+                client = dataqna_v1alpha.QuestionServiceAsyncClient()
 
                 # Initialize request argument(s)
                 user_feedback = dataqna_v1alpha.UserFeedback()
@@ -653,7 +674,7 @@ class QuestionServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.update_user_feedback(request=request)
+                response = await client.update_user_feedback(request=request)
 
                 # Handle the response
                 print(response)
@@ -723,7 +744,12 @@ class QuestionServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -737,7 +763,9 @@ class QuestionServiceAsyncClient:
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution("google-cloud-dataqna",).version,
+        gapic_version=pkg_resources.get_distribution(
+            "google-cloud-dataqna",
+        ).version,
     )
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
