@@ -16,33 +16,35 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
 except AttributeError:  # pragma: NO COVER
     OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
+from google.protobuf import any_pb2  # type: ignore
+from google.protobuf import field_mask_pb2  # type: ignore
+from google.protobuf import timestamp_pb2  # type: ignore
+
+from google.cloud.dataqna_v1alpha.types import user_feedback as gcd_user_feedback
 from google.cloud.dataqna_v1alpha.types import question
 from google.cloud.dataqna_v1alpha.types import question as gcd_question
 from google.cloud.dataqna_v1alpha.types import question_service
 from google.cloud.dataqna_v1alpha.types import user_feedback
-from google.cloud.dataqna_v1alpha.types import user_feedback as gcd_user_feedback
-from google.protobuf import any_pb2  # type: ignore
-from google.protobuf import field_mask_pb2  # type: ignore
-from google.protobuf import timestamp_pb2  # type: ignore
-from .transports.base import QuestionServiceTransport, DEFAULT_CLIENT_INFO
+
+from .transports.base import DEFAULT_CLIENT_INFO, QuestionServiceTransport
 from .transports.grpc import QuestionServiceGrpcTransport
 from .transports.grpc_asyncio import QuestionServiceGrpcAsyncIOTransport
 
@@ -61,7 +63,10 @@ class QuestionServiceClientMeta(type):
     _transport_registry["grpc"] = QuestionServiceGrpcTransport
     _transport_registry["grpc_asyncio"] = QuestionServiceGrpcAsyncIOTransport
 
-    def get_transport_class(cls, label: str = None,) -> Type[QuestionServiceTransport]:
+    def get_transport_class(
+        cls,
+        label: str = None,
+    ) -> Type[QuestionServiceTransport]:
         """Returns an appropriate transport class.
 
         Args:
@@ -183,10 +188,16 @@ class QuestionServiceClient(metaclass=QuestionServiceClientMeta):
         return self._transport
 
     @staticmethod
-    def question_path(project: str, location: str, question: str,) -> str:
+    def question_path(
+        project: str,
+        location: str,
+        question: str,
+    ) -> str:
         """Returns a fully-qualified question string."""
         return "projects/{project}/locations/{location}/questions/{question}".format(
-            project=project, location=location, question=question,
+            project=project,
+            location=location,
+            question=question,
         )
 
     @staticmethod
@@ -199,10 +210,16 @@ class QuestionServiceClient(metaclass=QuestionServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def user_feedback_path(project: str, location: str, question: str,) -> str:
+    def user_feedback_path(
+        project: str,
+        location: str,
+        question: str,
+    ) -> str:
         """Returns a fully-qualified user_feedback string."""
         return "projects/{project}/locations/{location}/questions/{question}/userFeedback".format(
-            project=project, location=location, question=question,
+            project=project,
+            location=location,
+            question=question,
         )
 
     @staticmethod
@@ -215,7 +232,9 @@ class QuestionServiceClient(metaclass=QuestionServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_billing_account_path(billing_account: str,) -> str:
+    def common_billing_account_path(
+        billing_account: str,
+    ) -> str:
         """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
@@ -228,9 +247,13 @@ class QuestionServiceClient(metaclass=QuestionServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_folder_path(folder: str,) -> str:
+    def common_folder_path(
+        folder: str,
+    ) -> str:
         """Returns a fully-qualified folder string."""
-        return "folders/{folder}".format(folder=folder,)
+        return "folders/{folder}".format(
+            folder=folder,
+        )
 
     @staticmethod
     def parse_common_folder_path(path: str) -> Dict[str, str]:
@@ -239,9 +262,13 @@ class QuestionServiceClient(metaclass=QuestionServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_organization_path(organization: str,) -> str:
+    def common_organization_path(
+        organization: str,
+    ) -> str:
         """Returns a fully-qualified organization string."""
-        return "organizations/{organization}".format(organization=organization,)
+        return "organizations/{organization}".format(
+            organization=organization,
+        )
 
     @staticmethod
     def parse_common_organization_path(path: str) -> Dict[str, str]:
@@ -250,9 +277,13 @@ class QuestionServiceClient(metaclass=QuestionServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_project_path(project: str,) -> str:
+    def common_project_path(
+        project: str,
+    ) -> str:
         """Returns a fully-qualified project string."""
-        return "projects/{project}".format(project=project,)
+        return "projects/{project}".format(
+            project=project,
+        )
 
     @staticmethod
     def parse_common_project_path(path: str) -> Dict[str, str]:
@@ -261,10 +292,14 @@ class QuestionServiceClient(metaclass=QuestionServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_location_path(project: str, location: str,) -> str:
+    def common_location_path(
+        project: str,
+        location: str,
+    ) -> str:
         """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
-            project=project, location=location,
+            project=project,
+            location=location,
         )
 
     @staticmethod
@@ -436,6 +471,7 @@ class QuestionServiceClient(metaclass=QuestionServiceClientMeta):
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
                 always_use_jwt_access=True,
+                api_audience=client_options.api_audience,
             )
 
     def get_question(
@@ -526,7 +562,12 @@ class QuestionServiceClient(metaclass=QuestionServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -633,7 +674,12 @@ class QuestionServiceClient(metaclass=QuestionServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -737,7 +783,12 @@ class QuestionServiceClient(metaclass=QuestionServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -826,7 +877,12 @@ class QuestionServiceClient(metaclass=QuestionServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -844,7 +900,6 @@ class QuestionServiceClient(metaclass=QuestionServiceClientMeta):
         r"""Updates user feedback. This creates user feedback if
         there was none before (upsert).
 
-
         .. code-block:: python
 
             from google.cloud import dataqna_v1alpha
@@ -932,7 +987,12 @@ class QuestionServiceClient(metaclass=QuestionServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -953,7 +1013,9 @@ class QuestionServiceClient(metaclass=QuestionServiceClientMeta):
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution("google-cloud-dataqna",).version,
+        gapic_version=pkg_resources.get_distribution(
+            "google-cloud-dataqna",
+        ).version,
     )
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
