@@ -14,33 +14,34 @@
 # limitations under the License.
 #
 import os
-import mock
 
-import grpc
-from grpc.experimental import aio
+# try/except added for compatibility with python < 3.8
+try:
+    from unittest import mock
+    from unittest.mock import AsyncMock
+except ImportError:
+    import mock
+
 import math
-import pytest
-from proto.marshal.rules.dates import DurationRule, TimestampRule
-
 
+from google.api_core import gapic_v1, grpc_helpers, grpc_helpers_async, path_template
 from google.api_core import client_options
 from google.api_core import exceptions as core_exceptions
-from google.api_core import gapic_v1
-from google.api_core import grpc_helpers
-from google.api_core import grpc_helpers_async
-from google.api_core import path_template
+import google.auth
 from google.auth import credentials as ga_credentials
 from google.auth.exceptions import MutualTLSChannelError
+from google.oauth2 import service_account
+import grpc
+from grpc.experimental import aio
+from proto.marshal.rules.dates import DurationRule, TimestampRule
+import pytest
+
 from google.cloud.dataqna_v1alpha.services.auto_suggestion_service import (
     AutoSuggestionServiceAsyncClient,
-)
-from google.cloud.dataqna_v1alpha.services.auto_suggestion_service import (
     AutoSuggestionServiceClient,
+    transports,
 )
-from google.cloud.dataqna_v1alpha.services.auto_suggestion_service import transports
 from google.cloud.dataqna_v1alpha.types import auto_suggestion_service
-from google.oauth2 import service_account
-import google.auth
 
 
 def client_cert_source_callback():
@@ -89,20 +90,26 @@ def test__get_default_mtls_endpoint():
 
 
 @pytest.mark.parametrize(
-    "client_class", [AutoSuggestionServiceClient, AutoSuggestionServiceAsyncClient,]
+    "client_class,transport_name",
+    [
+        (AutoSuggestionServiceClient, "grpc"),
+        (AutoSuggestionServiceAsyncClient, "grpc_asyncio"),
+    ],
 )
-def test_auto_suggestion_service_client_from_service_account_info(client_class):
+def test_auto_suggestion_service_client_from_service_account_info(
+    client_class, transport_name
+):
     creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_info"
     ) as factory:
         factory.return_value = creds
         info = {"valid": True}
-        client = client_class.from_service_account_info(info)
+        client = client_class.from_service_account_info(info, transport=transport_name)
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        assert client.transport._host == "dataqna.googleapis.com:443"
+        assert client.transport._host == ("dataqna.googleapis.com:443")
 
 
 @pytest.mark.parametrize(
@@ -131,23 +138,33 @@ def test_auto_suggestion_service_client_service_account_always_use_jwt(
 
 
 @pytest.mark.parametrize(
-    "client_class", [AutoSuggestionServiceClient, AutoSuggestionServiceAsyncClient,]
+    "client_class,transport_name",
+    [
+        (AutoSuggestionServiceClient, "grpc"),
+        (AutoSuggestionServiceAsyncClient, "grpc_asyncio"),
+    ],
 )
-def test_auto_suggestion_service_client_from_service_account_file(client_class):
+def test_auto_suggestion_service_client_from_service_account_file(
+    client_class, transport_name
+):
     creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_file"
     ) as factory:
         factory.return_value = creds
-        client = client_class.from_service_account_file("dummy/file/path.json")
+        client = client_class.from_service_account_file(
+            "dummy/file/path.json", transport=transport_name
+        )
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        client = client_class.from_service_account_json("dummy/file/path.json")
+        client = client_class.from_service_account_json(
+            "dummy/file/path.json", transport=transport_name
+        )
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        assert client.transport._host == "dataqna.googleapis.com:443"
+        assert client.transport._host == ("dataqna.googleapis.com:443")
 
 
 def test_auto_suggestion_service_client_get_transport_class():
@@ -214,6 +231,7 @@ def test_auto_suggestion_service_client_client_options(
             quota_project_id=None,
             client_info=transports.base.DEFAULT_CLIENT_INFO,
             always_use_jwt_access=True,
+            api_audience=None,
         )
 
     # Check the case api_endpoint is not provided and GOOGLE_API_USE_MTLS_ENDPOINT is
@@ -231,6 +249,7 @@ def test_auto_suggestion_service_client_client_options(
                 quota_project_id=None,
                 client_info=transports.base.DEFAULT_CLIENT_INFO,
                 always_use_jwt_access=True,
+                api_audience=None,
             )
 
     # Check the case api_endpoint is not provided and GOOGLE_API_USE_MTLS_ENDPOINT is
@@ -248,6 +267,7 @@ def test_auto_suggestion_service_client_client_options(
                 quota_project_id=None,
                 client_info=transports.base.DEFAULT_CLIENT_INFO,
                 always_use_jwt_access=True,
+                api_audience=None,
             )
 
     # Check the case api_endpoint is not provided and GOOGLE_API_USE_MTLS_ENDPOINT has
@@ -277,6 +297,25 @@ def test_auto_suggestion_service_client_client_options(
             quota_project_id="octopus",
             client_info=transports.base.DEFAULT_CLIENT_INFO,
             always_use_jwt_access=True,
+            api_audience=None,
+        )
+    # Check the case api_endpoint is provided
+    options = client_options.ClientOptions(
+        api_audience="https://language.googleapis.com"
+    )
+    with mock.patch.object(transport_class, "__init__") as patched:
+        patched.return_value = None
+        client = client_class(client_options=options, transport=transport_name)
+        patched.assert_called_once_with(
+            credentials=None,
+            credentials_file=None,
+            host=client.DEFAULT_ENDPOINT,
+            scopes=None,
+            client_cert_source_for_mtls=None,
+            quota_project_id=None,
+            client_info=transports.base.DEFAULT_CLIENT_INFO,
+            always_use_jwt_access=True,
+            api_audience="https://language.googleapis.com",
         )
 
 
@@ -354,6 +393,7 @@ def test_auto_suggestion_service_client_mtls_env_auto(
                 quota_project_id=None,
                 client_info=transports.base.DEFAULT_CLIENT_INFO,
                 always_use_jwt_access=True,
+                api_audience=None,
             )
 
     # Check the case ADC client cert is provided. Whether client cert is used depends on
@@ -388,6 +428,7 @@ def test_auto_suggestion_service_client_mtls_env_auto(
                         quota_project_id=None,
                         client_info=transports.base.DEFAULT_CLIENT_INFO,
                         always_use_jwt_access=True,
+                        api_audience=None,
                     )
 
     # Check the case client_cert_source and ADC client cert are not provided.
@@ -410,6 +451,7 @@ def test_auto_suggestion_service_client_mtls_env_auto(
                     quota_project_id=None,
                     client_info=transports.base.DEFAULT_CLIENT_INFO,
                     always_use_jwt_access=True,
+                    api_audience=None,
                 )
 
 
@@ -513,7 +555,9 @@ def test_auto_suggestion_service_client_client_options_scopes(
     client_class, transport_class, transport_name
 ):
     # Check the case scopes are provided.
-    options = client_options.ClientOptions(scopes=["1", "2"],)
+    options = client_options.ClientOptions(
+        scopes=["1", "2"],
+    )
     with mock.patch.object(transport_class, "__init__") as patched:
         patched.return_value = None
         client = client_class(client_options=options, transport=transport_name)
@@ -526,6 +570,7 @@ def test_auto_suggestion_service_client_client_options_scopes(
             quota_project_id=None,
             client_info=transports.base.DEFAULT_CLIENT_INFO,
             always_use_jwt_access=True,
+            api_audience=None,
         )
 
 
@@ -564,6 +609,7 @@ def test_auto_suggestion_service_client_client_options_credentials_file(
             quota_project_id=None,
             client_info=transports.base.DEFAULT_CLIENT_INFO,
             always_use_jwt_access=True,
+            api_audience=None,
         )
 
 
@@ -584,6 +630,7 @@ def test_auto_suggestion_service_client_client_options_from_dict():
             quota_project_id=None,
             client_info=transports.base.DEFAULT_CLIENT_INFO,
             always_use_jwt_access=True,
+            api_audience=None,
         )
 
 
@@ -622,6 +669,7 @@ def test_auto_suggestion_service_client_create_channel_credentials_file(
             quota_project_id=None,
             client_info=transports.base.DEFAULT_CLIENT_INFO,
             always_use_jwt_access=True,
+            api_audience=None,
         )
 
     # test that the credentials from file are saved and used as the credentials.
@@ -654,11 +702,16 @@ def test_auto_suggestion_service_client_create_channel_credentials_file(
 
 
 @pytest.mark.parametrize(
-    "request_type", [auto_suggestion_service.SuggestQueriesRequest, dict,]
+    "request_type",
+    [
+        auto_suggestion_service.SuggestQueriesRequest,
+        dict,
+    ],
 )
 def test_suggest_queries(request_type, transport: str = "grpc"):
     client = AutoSuggestionServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -684,7 +737,8 @@ def test_suggest_queries_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = AutoSuggestionServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -701,7 +755,8 @@ async def test_suggest_queries_async(
     request_type=auto_suggestion_service.SuggestQueriesRequest,
 ):
     client = AutoSuggestionServiceAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -739,7 +794,7 @@ def test_suggest_queries_field_headers():
     # a field header. Set these to a non-empty value.
     request = auto_suggestion_service.SuggestQueriesRequest()
 
-    request.parent = "parent/value"
+    request.parent = "parent_value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(type(client.transport.suggest_queries), "__call__") as call:
@@ -753,7 +808,10 @@ def test_suggest_queries_field_headers():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "parent=parent/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "parent=parent_value",
+    ) in kw["metadata"]
 
 
 @pytest.mark.asyncio
@@ -766,7 +824,7 @@ async def test_suggest_queries_field_headers_async():
     # a field header. Set these to a non-empty value.
     request = auto_suggestion_service.SuggestQueriesRequest()
 
-    request.parent = "parent/value"
+    request.parent = "parent_value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(type(client.transport.suggest_queries), "__call__") as call:
@@ -782,7 +840,10 @@ async def test_suggest_queries_field_headers_async():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "parent=parent/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "parent=parent_value",
+    ) in kw["metadata"]
 
 
 def test_credentials_transport_error():
@@ -792,7 +853,8 @@ def test_credentials_transport_error():
     )
     with pytest.raises(ValueError):
         client = AutoSuggestionServiceClient(
-            credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+            credentials=ga_credentials.AnonymousCredentials(),
+            transport=transport,
         )
 
     # It is an error to provide a credentials file and a transport instance.
@@ -813,7 +875,8 @@ def test_credentials_transport_error():
     options.api_key = "api_key"
     with pytest.raises(ValueError):
         client = AutoSuggestionServiceClient(
-            client_options=options, transport=transport,
+            client_options=options,
+            transport=transport,
         )
 
     # It is an error to provide an api_key and a credential.
@@ -830,7 +893,8 @@ def test_credentials_transport_error():
     )
     with pytest.raises(ValueError):
         client = AutoSuggestionServiceClient(
-            client_options={"scopes": ["1", "2"]}, transport=transport,
+            client_options={"scopes": ["1", "2"]},
+            transport=transport,
         )
 
 
@@ -873,12 +937,28 @@ def test_transport_adc(transport_class):
         adc.assert_called_once()
 
 
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "grpc",
+    ],
+)
+def test_transport_kind(transport_name):
+    transport = AutoSuggestionServiceClient.get_transport_class(transport_name)(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
+    assert transport.kind == transport_name
+
+
 def test_transport_grpc_default():
     # A client should use the gRPC transport by default.
     client = AutoSuggestionServiceClient(
         credentials=ga_credentials.AnonymousCredentials(),
     )
-    assert isinstance(client.transport, transports.AutoSuggestionServiceGrpcTransport,)
+    assert isinstance(
+        client.transport,
+        transports.AutoSuggestionServiceGrpcTransport,
+    )
 
 
 def test_auto_suggestion_service_base_transport_error():
@@ -910,6 +990,14 @@ def test_auto_suggestion_service_base_transport():
     with pytest.raises(NotImplementedError):
         transport.close()
 
+    # Catch all for all remaining methods and properties
+    remainder = [
+        "kind",
+    ]
+    for r in remainder:
+        with pytest.raises(NotImplementedError):
+            getattr(transport, r)()
+
 
 def test_auto_suggestion_service_base_transport_with_credentials_file():
     # Instantiate the base transport with a credentials file
@@ -921,7 +1009,8 @@ def test_auto_suggestion_service_base_transport_with_credentials_file():
         Transport.return_value = None
         load_creds.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport = transports.AutoSuggestionServiceTransport(
-            credentials_file="credentials.json", quota_project_id="octopus",
+            credentials_file="credentials.json",
+            quota_project_id="octopus",
         )
         load_creds.assert_called_once_with(
             "credentials.json",
@@ -974,6 +1063,28 @@ def test_auto_suggestion_service_transport_auth_adc(transport_class):
         )
 
 
+@pytest.mark.parametrize(
+    "transport_class",
+    [
+        transports.AutoSuggestionServiceGrpcTransport,
+        transports.AutoSuggestionServiceGrpcAsyncIOTransport,
+    ],
+)
+def test_auto_suggestion_service_transport_auth_gdch_credentials(transport_class):
+    host = "https://language.com"
+    api_audience_tests = [None, "https://language2.com"]
+    api_audience_expect = [host, "https://language2.com"]
+    for t, e in zip(api_audience_tests, api_audience_expect):
+        with mock.patch.object(google.auth, "default", autospec=True) as adc:
+            gdch_mock = mock.MagicMock()
+            type(gdch_mock).with_gdch_audience = mock.PropertyMock(
+                return_value=gdch_mock
+            )
+            adc.return_value = (gdch_mock, None)
+            transport_class(host=host, api_audience=t)
+            gdch_mock.with_gdch_audience.assert_called_once_with(e)
+
+
 @pytest.mark.parametrize(
     "transport_class,grpc_helpers",
     [
@@ -1058,24 +1169,40 @@ def test_auto_suggestion_service_grpc_transport_client_cert_source_for_mtls(
             )
 
 
-def test_auto_suggestion_service_host_no_port():
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "grpc",
+        "grpc_asyncio",
+    ],
+)
+def test_auto_suggestion_service_host_no_port(transport_name):
     client = AutoSuggestionServiceClient(
         credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="dataqna.googleapis.com"
         ),
+        transport=transport_name,
     )
-    assert client.transport._host == "dataqna.googleapis.com:443"
+    assert client.transport._host == ("dataqna.googleapis.com:443")
 
 
-def test_auto_suggestion_service_host_with_port():
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "grpc",
+        "grpc_asyncio",
+    ],
+)
+def test_auto_suggestion_service_host_with_port(transport_name):
     client = AutoSuggestionServiceClient(
         credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="dataqna.googleapis.com:8000"
         ),
+        transport=transport_name,
     )
-    assert client.transport._host == "dataqna.googleapis.com:8000"
+    assert client.transport._host == ("dataqna.googleapis.com:8000")
 
 
 def test_auto_suggestion_service_grpc_transport_channel():
@@ -1083,7 +1210,8 @@ def test_auto_suggestion_service_grpc_transport_channel():
 
     # Check that channel is used if provided.
     transport = transports.AutoSuggestionServiceGrpcTransport(
-        host="squid.clam.whelk", channel=channel,
+        host="squid.clam.whelk",
+        channel=channel,
     )
     assert transport.grpc_channel == channel
     assert transport._host == "squid.clam.whelk:443"
@@ -1095,7 +1223,8 @@ def test_auto_suggestion_service_grpc_asyncio_transport_channel():
 
     # Check that channel is used if provided.
     transport = transports.AutoSuggestionServiceGrpcAsyncIOTransport(
-        host="squid.clam.whelk", channel=channel,
+        host="squid.clam.whelk",
+        channel=channel,
     )
     assert transport.grpc_channel == channel
     assert transport._host == "squid.clam.whelk:443"
@@ -1224,7 +1353,9 @@ def test_parse_common_billing_account_path():
 
 def test_common_folder_path():
     folder = "whelk"
-    expected = "folders/{folder}".format(folder=folder,)
+    expected = "folders/{folder}".format(
+        folder=folder,
+    )
     actual = AutoSuggestionServiceClient.common_folder_path(folder)
     assert expected == actual
 
@@ -1242,7 +1373,9 @@ def test_parse_common_folder_path():
 
 def test_common_organization_path():
     organization = "oyster"
-    expected = "organizations/{organization}".format(organization=organization,)
+    expected = "organizations/{organization}".format(
+        organization=organization,
+    )
     actual = AutoSuggestionServiceClient.common_organization_path(organization)
     assert expected == actual
 
@@ -1260,7 +1393,9 @@ def test_parse_common_organization_path():
 
 def test_common_project_path():
     project = "cuttlefish"
-    expected = "projects/{project}".format(project=project,)
+    expected = "projects/{project}".format(
+        project=project,
+    )
     actual = AutoSuggestionServiceClient.common_project_path(project)
     assert expected == actual
 
@@ -1280,7 +1415,8 @@ def test_common_location_path():
     project = "winkle"
     location = "nautilus"
     expected = "projects/{project}/locations/{location}".format(
-        project=project, location=location,
+        project=project,
+        location=location,
     )
     actual = AutoSuggestionServiceClient.common_location_path(project, location)
     assert expected == actual
@@ -1305,7 +1441,8 @@ def test_client_with_default_client_info():
         transports.AutoSuggestionServiceTransport, "_prep_wrapped_messages"
     ) as prep:
         client = AutoSuggestionServiceClient(
-            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(),
+            client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
 
@@ -1314,7 +1451,8 @@ def test_client_with_default_client_info():
     ) as prep:
         transport_class = AutoSuggestionServiceClient.get_transport_class()
         transport = transport_class(
-            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(),
+            client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
 
@@ -1322,7 +1460,8 @@ def test_client_with_default_client_info():
 @pytest.mark.asyncio
 async def test_transport_close_async():
     client = AutoSuggestionServiceAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc_asyncio",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc_asyncio",
     )
     with mock.patch.object(
         type(getattr(client.transport, "grpc_channel")), "close"
@@ -1395,4 +1534,5 @@ def test_api_key_credentials(client_class, transport_class):
                 quota_project_id=None,
                 client_info=transports.base.DEFAULT_CLIENT_INFO,
                 always_use_jwt_access=True,
+                api_audience=None,
             )
